'''
Represents models for cluster management
'''

from splunk.models.base import SplunkAppObjModel
from splunk.models.field import Field, BoolField, EpochField, IntField, ListField, FloatField, FloatByteField, IntByteField, DictField


class ClusterMasterPeer(SplunkAppObjModel):
    '''
    Represents a master's cluster peer state
    '''

    resource            = 'cluster/master/peers' 

    buckets             = ListField(is_mutable=False)
    decommission_set    = ListField(is_mutable=False)
    host_port_pair      = Field(is_mutable=False)
    last_heartbeat      = EpochField(is_mutable=False)
    pending_job_count   = IntField(is_mutable=False)
    replication_port    = IntField(is_mutable=False)
    replication_use_ssl     = BoolField(is_mutable=False)
    label               = Field(is_mutable=False)
    status              = Field(is_mutable=False)
    status_counter      = DictField(is_mutable=False)
    search_state_counter= DictField(is_mutable=False)

class ClusterMasterGeneration(SplunkAppObjModel):
    '''
    Represents a master's generation info
    '''

    resource            = '/cluster/master/generation'

    generation_id       = IntField(is_mutable=False)
    generation_peers    = DictField(is_mutable=False)
    pending_generation_id = IntField(is_mutable=False)
    pending_last_attempt = IntField(is_mutable=False)
    pending_last_reason = Field(is_mutable=False)

class ClusterMasterBucket(SplunkAppObjModel):
    '''
    Represents a master's cluster bucket state
    '''

    resource            = 'cluster/master/buckets'

    bucket_size         = IntField(is_mutable=False)
    peers               = DictField(is_mutable=False)
    frozen              = BoolField(is_mutable=False)
    standalone          = BoolField(is_mutable=False)

class ClusterMasterInfo(SplunkAppObjModel):
    '''
    Represents a master node's state
    '''

    resource            = 'cluster/master/info'

    active_bundle       = DictField(is_mutable=False)
    buckets_to_fix      = ListField(is_mutable=False)
    initialized_flag    = BoolField(is_mutable=False)
    indexing_ready_flag = BoolField(is_mutable=False)
    label               = Field(is_mutable=False)
    latest_bundle       = DictField(is_mutable=False)
    rolling_restart_flag= BoolField(is_mutable=False)
    start_time          = IntField(is_mutable=False)

class ClusterSearchheadInfo(SplunkAppObjModel):
    '''
    Represents a searchhead node's state
    '''

    resource            = 'cluster/searchhead/generation'

    generation_id              = Field(is_mutable=False)
    generation_peers           = ListField(is_mutable=False)

class ClusterSlaveBucket(SplunkAppObjModel):
    '''
    Represents a slave's cluster bucket state
    '''

    resource            = 'cluster/slave/buckets'

    status              = Field(is_mutable=False)
    search_state        = Field(is_mutable=False)
    generations         = DictField(is_mutable=False)

class ClusterSlaveInfo(SplunkAppObjModel):
    '''
    Represents a slave node's state
    TODO
    '''
    resource            = 'cluster/slave/info'

    active_bundle          = DictField(is_mutable=False)
    base_generation_id     = IntField(is_mutable=False) 
    invalid_bundle_ids     = ListField(is_mutable=False)
    is_registered          = BoolField(is_mutable=False)
    is_shutdown            = BoolField(is_mutable=False)
    last_heartbeat_attempt = IntField(is_mutable=False)
    latest_bundle          = DictField(is_mutable=False)
    restart_state          = Field(is_mutable=False)
    status                 = Field(is_mutable=False)

class ClusterSlaveControl(SplunkAppObjModel):
    '''
    Represents a slave control endpoint
    TODO
    '''
    pass

class ClusterConfig(SplunkAppObjModel):
    '''
    Represents the current node
    '''

    resource            = 'cluster/config'


    cxn_timeout         = IntField()
    heartbeat_timeout   = IntField()
    mode                = Field()
    master_uri          = Field()
    ip                  = Field()
    max_jobs            = IntField(is_mutable=False)
    ping_flag           = BoolField(is_mutable=False)
    quiet_period        = IntField()
    replication_factor  = IntField()
    rcv_timeout         = IntField()
    restart_timeout     = IntField()
    search_factor       = IntField()
    send_timeout        = IntField()
    rep_cxn_timeout     = IntField()
    rep_send_timeout    = IntField()
    rep_rcv_timeout     = IntField()
    rep_max_send_timeout= IntField()
    rep_max_rcv_timeout = IntField()
    disabled            = BoolField(is_mutable=False)
    max_peer_build_load = IntField(is_mutable=False)
    max_peer_rep_load   = IntField(is_mutable=False)
    secret              = Field()
    heartbeat_period    = IntField(is_mutable=False)
    replication_port    = IntField()
